CLIENT_ID_KEY = "client_id"
NUM_SAMPLES_KEY = "num_samples"
UPDATE_KEY = "update"
FLOPS_KEY = "flops"
METRICS_KEY = "metrics"
ROUND_KEY = "round"
